@@ -9,8 +9,11 @@ class Preshift(object):
     Holder class for information prior to shifting
     """
 
-    def __init__(self, self_obj, args, kwargs):
+    def __init__(self, self_obj, call_args, call_kwargs):
         self.obj = self_obj
         self.obj_length = safe_obj_length(self_obj)
-        self.args = args or []
-        self.kwargs = kwargs or {}
+        self.args = call_args or []
+        self.kwargs = call_kwargs or {}
+
+    def __repr__(self):
+        return "<Preshift({}, {}, {})>".format(self.obj, self.args, self.kwargs)
