@@ -9,15 +9,7 @@ class DataflowRule(TriggerRule):
     Rule class used for all dataflow rules. Hash computation includes events.
     """
 
-    def create_finding(self, properties, events=None):
-        finding = super(TriggerRule, self).create_finding(properties, events=events)
-
-        if events is not None:
-            finding.events.extend(events)
-
-        return finding
-
-    def update_preflight_hash(self, hasher, events=None):
+    def update_preflight_hash(self, hasher, events=None, **kwargs):
         """
         This gets called from `create_finding` in the base class
 
