@@ -6,10 +6,17 @@ from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.assess.rules.base_rule import BaseRule
 from contrast.agent.assess.utils import get_properties
+from contrast.agent.settings_state import SettingsState
+from contrast.api import Finding
 from contrast.utils.decorators import cached_property
 from contrast.utils.string_utils import equals_ignore_case
 
 
+import logging
+
+logger = logging.getLogger("contrast")
+
+
 class TriggerRule(BaseRule):
     UNTRUSTED = "UNTRUSTED"
 
@@ -133,6 +140,30 @@ class TriggerRule(BaseRule):
 
         return trigger_nodes
 
+    def create_finding(self, properties, node, target, **kwargs):
+        return Finding(self, properties, **kwargs).get_finding_msg()
+
+    def build_and_append_finding(self, context, properties, node, target, **kwargs):
+        finding_msg = self.create_finding(properties, node, target, **kwargs)
+
+        # if after creating the finding, we discover that this finding already exists
+        # in context.activity, then do not add it and return early
+        for curr_finding in context.activity.findings:
+            if finding_msg.hash_code == curr_finding.hash_code:
+                return
+
+        context.activity.findings.extend([finding_msg])
+
+        settings = SettingsState()
+        context.activity.finding_tags = settings.config.get("assess.tags", "")
+
+        logger.debug(
+            "Trigger %s detected: %s triggered %s",
+            node.name,
+            str(id(target)),
+            self.name,
+        )
+
     JSON_NAME = "name"
     JSON_DISALLOWED_TAGS = "disallowed_tags"
     JSON_REQUIRED_TAGS = "required_tags"
