@@ -12,6 +12,7 @@ from contrast.agent import patch_controller, service_client, scope
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy.trigger_policy import TriggerPolicy
 from contrast.agent.assess.preflight import update_preflight_hashes
+from contrast.agent.assess.rules.providers.enable import enable_providers
 from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
 from contrast.agent.settings_state import SettingsState
 from contrast.agent.speedracer_input_analysis import get_input_analysis
@@ -74,10 +75,16 @@ class BaseMiddleware(RoutesMixin):
             logger.error("Unable to initialize Contrast Agent.")
             return
 
+        if not self.settings.is_agent_config_enabled():
+            logger.warning("Contrast Agent is not enabled.")
+            return
+
         setup_agent_logger(self.settings.config)
         self.log_environment()
 
-        service_client.send_startup_messages()
+        if not self.initialize_service_client():
+            logger.error("Unable to initialize Contrast Agent.")
+            return
 
         self.initialize_libraries()
 
@@ -91,6 +98,10 @@ class BaseMiddleware(RoutesMixin):
 
         patch_controller.enable_patches()
 
+        if self.settings.is_assess_enabled():
+            enable_providers()
+            self.scan_configs()
+
         self.log_finish_initialize()
 
         BaseMiddleware._loaded = True
@@ -99,12 +110,24 @@ class BaseMiddleware(RoutesMixin):
         """
         Initialize agent settings.
 
-        Returns True on settings being initialized and False if loading the
-        configuration failed.
+        Returns True on settings being initialized and False if any failure.
         """
         try:
             self.settings = SettingsState(app_name=app_name)
-        except (ContrastServiceException, DisableAgentException) as e:
+        except (Exception, DisableAgentException) as e:
+            logger.error(e)
+            return False
+        return True
+
+    def initialize_service_client(self):
+        """
+        Initialize connection to service.
+
+        Returns True on service being initialized and False if any failure.
+        """
+        try:
+            service_client.send_startup_messages()
+        except (Exception, ContrastServiceException) as e:
             logger.error(e)
             return False
         return True
@@ -168,7 +191,6 @@ class BaseMiddleware(RoutesMixin):
             except ContrastServiceException:
                 return False
 
-        # initialize_service_client should have set the connection to connected
         return service_client.is_connected()
 
     def call_with_agent(self, context, environ, start_response):
@@ -207,10 +229,11 @@ class BaseMiddleware(RoutesMixin):
             context.activity,
         ]
 
-        # TODO: PYT-972
-        # Currently we do not report an observed route if the route signature is empty
-        # and/or missing. In the future, we want to try to generate a reasonable
-        # substitute for the signature value if possible.
+        # Currently we do not report an observed route if the route signature is empty.
+        # As a team we've decided there isn't a meaningful default signature value
+        # we can provide to customers. If a route doesn't show up in Contrast UI,
+        # it may be due to its missing signature. In this scenario, we will have to work
+        # with the customer directly to understand why the signature was not created.
         if self.settings.is_assess_enabled() and context.observed_route.signature:
             final_messages.append(context.observed_route)
 
@@ -533,3 +556,12 @@ class BaseMiddleware(RoutesMixin):
             self.id,
             self.LOGS_SEPARATOR,
         )
+
+    def scan_configs(self):
+        """
+        Run config scanning rules for assess
+
+        Not all frameworks we support will necessarily have config scanning rules.
+        Those that do should override this method.
+        """
+        logger.debug("No config scanning rules for %s", self.__class__.__name__)
