@@ -13,7 +13,6 @@ from contrast.patches import (
     cs_str as cs_str_patches,
     register_assess_patches,
     register_common_patches,
-    register_protect_patches,
 )
 from contrast.utils.namespace import Namespace
 from contrast.utils.patch_utils import repatch_imported_modules
@@ -33,7 +32,16 @@ def enable_assess_patches():
     if module.enabled:
         return
 
-    module.hook = cs_str.enable(logger)
+    try:
+        module.hook = cs_str.enable(logger)
+    except RuntimeError:
+        logger.error(
+            "Local python builds on OSX may lead to 'Failed to unprotect memory'"
+        )
+        logger.error(
+            "If this is applies to you, try running `contrast-fix-interpreter-permissions`"
+        )
+        raise
 
     # Enable any string patches that need to be applied through Python
     cs_str_patches.patch_strtype_methods()
@@ -63,7 +71,6 @@ def _enable_patches():
 
     if settings.is_protect_enabled():
         register_common_patches()
-        register_protect_patches()
 
         logger.debug("adding protect policy")
         register_import_hooks(protect_mode=True)
