@@ -72,9 +72,6 @@ def patch(owner, name, patch=None, force=False):
             owner,
         )
 
-    # TODO: PYT-696 this is a hack that only definitely works for sqlite3.
-    # It is not a satisfactory resolution to PYT-696 without at least some more investigation.
-    # This should be investigated for cases like `open`, or cases where `owner` is a module.
     setattr(owner, name, patch) if not force else set_attr_on_type(owner, name, patch)
     register_patch(owner, name, orig_attr)
 
@@ -108,7 +105,6 @@ def reverse_patch(owner, name, force=False):
         )
         return
 
-    # TODO: PYT-696 - see note above, in `patch`
     setattr(owner, name, orig_attr) if not force else set_attr_on_type(
         owner, name, orig_attr
     )
@@ -135,6 +131,9 @@ def reverse_patches_by_owner(owner, force=False):
     :param owner: module or class that owns the attribute being reverse patched
     :param force: use set_attr_on_type instead of setattr to force the reverse patch to succeed
     """
+    if not id(owner) in module.patches_by_owner:
+        return
+
     for name in list(module.patches_by_owner[id(owner)]):
         reverse_patch(owner, name, force=force)
 
