@@ -6,6 +6,7 @@ from contrast.agent.protect.rule.deserialization.pickle_searcher import PickleSe
 from contrast.agent.protect.rule.deserialization.yaml_searcher import YAMLSearcher
 from contrast.api.dtm_pb2 import AttackResult, UserInput
 from contrast.api.settings_pb2 import InputAnalysisResult
+from contrast.extern import six
 from contrast.utils.decorators import set_context
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.string_utils import ends_with_any
@@ -49,6 +50,62 @@ class Deserialization(BaseRule):
     def is_postfilter(self):
         return False
 
+    def skip_protect_analysis(self, user_input, args, kwargs):
+        """
+        Deserialization rule will receive io streams as user input.
+
+        :return: Bool if to skip running protect infilter
+        """
+        if not user_input:
+            return True
+
+        # checking if obj has attr "read" is more robust than using isinstance
+        if hasattr(user_input, "read"):
+            return False
+
+        return super(Deserialization, self).skip_protect_analysis(
+            user_input, args, kwargs
+        )
+
+    def convert_input(self, user_input):
+        if isinstance(user_input, (six.string_types, six.binary_type)):
+            data = user_input
+        else:
+            data = self._get_stream_data(user_input)
+
+        return super(Deserialization, self).convert_input(data)
+
+    def _get_stream_data(self, user_input):
+        """
+        Get data from a stream object but make sure to return the stream position
+        to the original location.
+        
+        :param user_input: obj we expect to be a stream with attrs read, tell and seek
+        :return: str or bytes
+        """
+        if not all(hasattr(user_input, attr) for attr in ["read", "tell", "seek"]):
+            return ""
+
+        # Find current steam position
+        try:
+            seek_loc = user_input.tell()
+        except Exception:
+            seek_loc = 0
+
+        # Read the object data
+        try:
+            data = user_input.read()
+        except Exception:
+            data = ""
+
+        # Return object to original stream position so it can be re-read
+        try:
+            user_input.seek(seek_loc)
+        except Exception:
+            pass
+
+        return data
+
     @set_context("in_infilter")
     def infilter(self, match_string, **kwargs):
         logger.debug("PROTECT: Infilter for %s", self.name)
