@@ -54,6 +54,9 @@ class RequestContext(object):
         """
         self.response = response
 
+        if not SettingsState().response_scanning_enabled:
+            return
+
         self.activity.http_response.response_code = response.status_code
 
         # From the dtm for normalized_response_headers:
