@@ -13,9 +13,9 @@ from . import (
     cs_re,
     threading_patch,
     exec_and_eval,
-    pickle_patch,
+    lxml_patch,
     pycryptodome_patch,
-    pyyaml_patch,
+    pyramid_patch,
 )
 from .databases import (
     mysql_connector_patch,
@@ -43,18 +43,13 @@ COMMON_PATCH_MODULES = (
 )
 
 
-PROTECT_PATCH_MODULES = (
-    # These patches are handled by policy on the assess side
-    pickle_patch,
-    pyyaml_patch,
-)
-
-
 ASSESS_PATCH_MODULES = (
     cs_cstringio,
     cs_io,
     cs_re,
     exec_and_eval,
+    lxml_patch,
+    pyramid_patch,
 )
 
 
@@ -72,11 +67,6 @@ def register_common_patches():
         register_module_patches(module, "common")
 
 
-def register_protect_patches():
-    for module in PROTECT_PATCH_MODULES:
-        register_module_patches(module, "protect")
-
-
 def register_assess_patches():
     for module in ASSESS_PATCH_MODULES:
         register_module_patches(module, "assess")
