@@ -2,8 +2,9 @@
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.wrapt import register_post_import_hook
-
+import sys
 import contrast
+from contrast.agent.policy import patch_manager
 from contrast.patches.databases import dbapi2
 from contrast.utils import inventory_utils
 from contrast.utils.patch_utils import patch_cls_or_instance
@@ -54,3 +55,15 @@ def instrument_pysqlite2_dbapi2(pysqlite2):
 def register_patches():
     register_post_import_hook(instrument_sqlite_dbapi2, SQLITE3)
     register_post_import_hook(instrument_pysqlite2_dbapi2, PYSQLITE2_DBAPI2)
+
+
+def reverse_patches():
+    sqlite3 = sys.modules.get(SQLITE3)
+    if sqlite3:
+        patch_manager.reverse_patches_by_owner(sqlite3)
+        patch_manager.reverse_patches_by_owner(sqlite3.Cursor, force=True)
+
+    psqlite = sys.modules.get(PYSQLITE2_DBAPI2)
+    if psqlite:
+        patch_manager.reverse_patches_by_owner(psqlite)
+        patch_manager.reverse_patches_by_owner(psqlite.Cursor, force=True)
