@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+import sys
 from contrast.extern import six
 from contrast.extern.wrapt import register_post_import_hook
-
+from contrast.agent.policy import patch_manager
 from contrast.assess_extensions import cs_str
 from contrast.utils.patch_utils import patch_cls_or_instance
 
@@ -56,3 +57,11 @@ def patch_threading(threading_module):
 
 def register_patches():
     register_post_import_hook(patch_threading, "threading")
+
+
+def reverse_patches():
+    threading = sys.modules.get("threading")
+    if not threading:
+        return
+
+    patch_manager.reverse_patches_by_owner(threading.Thread)
