@@ -13,6 +13,7 @@ from app.urls import urlpatterns
 from django import __version__ as django_version
 from django.utils.html import escape
 from django.test import Client
+from contrast.agent.protect.rule.deserialization_rule import Deserialization
 from contrast.api.dtm_pb2 import AttackResult, ObservedRoute
 from contrast.api.settings_pb2 import ProtectionRule
 from contrast.utils.exceptions.security_exception import SecurityException
@@ -171,6 +172,11 @@ class DjangoProtectTestMixinBlock(DjangoProtectNoSqliTestMixin):
             "name": "Path Traversal",
             "mode": ProtectionRule.BLOCK,
         },
+        {
+            "mode": ProtectionRule.BLOCK,
+            "id": Deserialization.NAME,
+            "name": "Untrusted Deserialization",
+        },
         {"id": "nosql-injection", "name": "NosQLI", "mode": ProtectionRule.BLOCK},
     ]
 
@@ -193,6 +199,30 @@ class DjangoProtectTestMixinBlock(DjangoProtectNoSqliTestMixin):
         assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
         assert self.request_context.activity.results[0].rule_id == "cmd-injection"
 
+    @pytest.mark.parametrize("method_name", ["get", "post"])
+    @pytest.mark.parametrize("trigger", ["pickle-load", "pickle-loads"])
+    def test_pickle(self, trigger, method_name):
+        param_val = "csubprocess\ncheck_output\n(S'ls'\ntR."
+
+        params = dict(user_input=param_val)
+
+        c = Client()
+        method = getattr(c, method_name)
+
+        if django_version < "1.11":
+            # SecurityException is not raised by legacy django middleware client
+            method("/vulnpy/deserialization/{}".format(trigger), params)
+        else:
+            with pytest.raises(SecurityException):
+                method("/vulnpy/deserialization/{}".format(trigger), params)
+
+        assert len(self.request_context.activity.results) == 1
+        assert self.request_context.activity.results[0].response == AttackResult.BLOCKED
+        assert (
+            self.request_context.activity.results[0].rule_id
+            == "untrusted-deserialization"
+        )
+
 
 class DjangoAssessTestMixin(object):
     """
@@ -423,41 +453,28 @@ class DjangoAssessTestMixin(object):
             )
 
     @pytest.mark.parametrize("method_name", ["get", "post"])
+    @pytest.mark.parametrize("trigger", ["pickle-load", "pickle-loads"])
     @mocks.build_finding
-    def test_ud_pickle(self, mocked, method_name):
+    def test_ud_pickle(self, mocked, trigger, method_name):
         param_val = "(dp0\nS'lion'\np1\nS'yellow'\np2\nsS'kitty'\np3\nS'red'\np4\ns."
 
         params = dict(user_input=param_val)
 
         method = getattr(self.client, method_name)
-        method("/untrusted-pickle/", params)
+        method("/vulnpy/deserialization/{}".format(trigger), params)
 
         assert (
             self.request_context.activity.findings[0].rule_id
             == "untrusted-deserialization"
         )
 
+    @pytest.mark.parametrize("trigger", ["yaml-load", "yaml-load-all"])
     @mocks.build_finding
-    def test_ud_yaml(self, mocked):
-        param_val = '!!map {\n  ? !!str "goodbye"\n}'
-        response = self.client.get("/untrusted-yaml/", {"user_input": param_val})
+    def test_ud_yaml(self, mocked, trigger):
+        param_val = "!!map {\n" '  ? !!str "goodbye"\n' "}"
 
-        validate_finding(
-            self.request_context.activity.findings,
-            response,
-            param_val,
-            param_val,
-            mocked,
-            "untrusted-deserialization",
-            1,
-        )
-
-    @mocks.build_finding
-    def test_ud_yaml_all(self, mocked):
-        param_val = '!!map {\n  ? !!str "goodbye"\n}'
-        response = self.client.get(
-            "/untrusted-yaml/", {"user_input": param_val}, load_all=True
-        )
+        path = "/vulnpy/deserialization/{}/".format(trigger, param_val)
+        response = self.client.get(path, {"user_input": param_val})
 
         validate_finding(
             self.request_context.activity.findings,
@@ -483,12 +500,15 @@ class DjangoAssessTestMixin(object):
         assert not mocked.called
         assert len(self.request_context.activity.findings) == 0
 
-    @pytest.mark.parametrize("xml_url", ["/xxe-pulldom/", "/xxe-lxml/", "/xxe-sax/"])
+    @pytest.mark.parametrize(
+        "xml_url",
+        ["xml-dom-pulldom-parsestring", "lxml-etree-fromstring", "xml-sax-parsestring"],
+    )
     @mocks.build_finding
-    def test_xxe_urls(self, mocked, xml_url):
+    def test_xxe(self, mocked, xml_url):
         param_val = "<root>attack</root>"
 
-        response = self.client.get(xml_url, {"user_input": param_val})
+        response = self.client.get("/vulnpy/xxe/" + xml_url, {"user_input": param_val})
 
         validate_finding(
             self.request_context.activity.findings,
@@ -745,11 +765,18 @@ class DjangoAssessTestMixin(object):
         assert second_finding.hash_code != first_finding.hash_code
         assert second_finding.preflight != first_finding.hash_code
 
-    def test_untrusted_exec(self):
-        user_input = "x = 1 + 2 + 3"
-        self.client.get("/untrusted-exec/", dict(user_input=user_input))
+    @pytest.mark.parametrize("endpoint", ["exec", "eval", "compile"])
+    def test_untrusted_code_exec(self, endpoint):
+        user_input = "1 + 2 + 3"
+        self.client.get(
+            "/vulnpy/unsafe_code_exec/{}/".format(endpoint), dict(user_input=user_input)
+        )
 
-        assert len(self.request_context.activity.findings) == 2
+        assert (
+            len(self.request_context.activity.findings) == 2
+            if six.PY2 and endpoint == "eval"
+            else 1
+        )
         assert (
             self.request_context.activity.findings[0].rule_id
             == u"unsafe-code-execution"
@@ -788,6 +815,15 @@ class DjangoAssessTestMixin(object):
 
         assert_event_sources(findings, "database", {"database": "TAINTED_DATABASE"})
 
+    @pytest.mark.parametrize("module_name", ["xml", "lxml"])
+    def test_xpath_injection(self, module_name):
+        query = ".//*[@name='whatever']"
+        self.client.get("/xpath-injection/", dict(query=query, module=module_name))
+
+        findings = self.request_context.activity.findings
+        assert len(findings) == 1
+        assert findings[0].rule_id == "xpath-injection"
+
 
 class DjangoRouteCoverageTestMixin(object):
     @mock_build_update_messages
@@ -889,6 +925,20 @@ class DjangoRouteCoverageTestMixin(object):
             1 if six.PY3 else 2,
         )
 
+    @pytest.mark.parametrize("setdefault", [False, True])
+    def test_trust_boundary_violation(self, setdefault):
+        self.client.get(
+            "/trust-boundary-violation/?user_input=whatever&setdefault={}".format(
+                setdefault
+            )
+        )
+
+        assert len(self.request_context.activity.findings) == 1
+        assert (
+            self.request_context.activity.findings[0].rule_id
+            == "trust-boundary-violation"
+        )
+
 
 class DjangoAssessTestDynamicSources(object):
 
@@ -981,3 +1031,10 @@ class DjangoAssessTestDynamicSources(object):
         method(route, HTTP_TEST_HEADER="whatever", use_environ=use_environ)
 
         validate_header_sources(self.request_context.activity.findings, source_name)
+
+    @pytest.mark.parametrize("method_name", ["get", "post"])
+    def test_http_method_not_source(self, method_name):
+        method = getattr(self.client, method_name)
+        method("/dynamic-sources/", dict(source="http_method"))
+
+        assert len(self.request_context.activity.findings) == 0
