@@ -10,10 +10,12 @@ import json
 import os
 import pickle
 
+import lxml.etree
+from xml.etree import ElementTree
+
 import six  # pylint: disable=did-not-import-extern
 from six.moves import http_client as http  # pylint: disable=did-not-import-extern
 import mock
-import yaml
 
 from django import __version__ as django_version
 from django.contrib.auth import logout as DjangoLogout
@@ -145,31 +147,6 @@ def nosqli(request):
     return render(request, "nosqli.html", {"result": result})
 
 
-@csrf_exempt
-def untrusted_yaml(request):
-    """
-    !!map {
-      ? !!str "goodbye"
-      : !!python/object/apply:subprocess.check_output [
-        !!str "ls",
-      ],
-    }
-    """
-    user_input = request.GET.get("user_input", "")
-    load_all = request.environ.get("load_all", False)
-
-    if user_input:
-        if load_all:
-            # load_all returns a generator so we need to force the load
-            list(yaml.load_all(user_input))
-        else:
-            yaml.load(user_input)
-
-    return render(
-        request, "deserialization_yaml.html", {"user_input": "ud", "result": "res"}
-    )
-
-
 def run_pymongo(method, user_input, with_kwarg):
     """
     :param method: Pymongo Collection method to run
@@ -288,42 +265,6 @@ def cmdi_file(request):
     return render(request, "cmdi.html")
 
 
-@csrf_exempt
-@require_http_methods(["GET", "POST"])
-def untrusted_pickle(request):
-    """
-    Passes untrusted input to pickle
-
-    GET uses pickle.loads with the encoded parameter
-    POST users pickle.load with a stream built from the parameter
-    """
-    result = ""
-
-    if request.method == "GET":
-        user_input = request.GET.get("user_input", "")
-        user_input = user_input.encode("utf-8")
-
-        if user_input:
-            try:
-                result = pickle.loads(user_input)
-            except Exception as e:
-                result = str(e)
-
-    elif request.method == "POST":
-        user_input = request.POST.get("user_input", "")
-        user_input = io.BytesIO(six.ensure_binary(user_input))
-
-        if user_input:
-            try:
-                result = pickle.load(user_input)
-            except Exception as e:
-                result = str(e)
-
-    return render(
-        request, "deserialization.html", {"user_input": "ud", "result": result}
-    )
-
-
 @require_http_methods(["GET"])
 def stream_source(request):
     """
@@ -453,13 +394,6 @@ def two_vulns(request):
     return HttpResponse("<p>{}</p>".format(user_input))
 
 
-def untrusted_exec(request):
-    user_input = request.GET.get("user_input", "1 + 2")
-    exec (user_input)
-    # This is xss too...
-    return HttpResponse("<p>executed statement: {}</p>".format(user_input))
-
-
 def untrusted_execfile(request):
     user_input = request.GET.get("user_input", "attack.py")
 
@@ -472,6 +406,27 @@ def untrusted_execfile(request):
     return HttpResponse("<p>executed statement: {}</p>".format(user_input))
 
 
+def xpath_injection(request):
+    query = request.GET.get("query", "")
+    module = request.GET.get("module", "")
+
+    xml_doc = """<foo><bar name='whatever'>42</bar></foo>"""
+
+    result = None
+
+    try:
+        if module == "xml":
+            node = ElementTree.fromstring(xml_doc)
+            result = node.find(query)
+        elif module == "lxml":
+            node = lxml.etree.fromstring(xml_doc)
+            result = node.find(query)
+    except Exception as e:
+        result = str(e)
+
+    return HttpResponse("<p>result = {}</p>".format(result))
+
+
 def logout(request):
     DjangoLogout(request)
     return render(request, "logout.html")
@@ -505,6 +460,8 @@ def get_dynamic_source(request, request_dict, source):
         user_input = (
             request.headers["Referer"] if six.PY3 else request.META["HTTP_REFERER"]
         )
+    elif source == "http_method":
+        user_input = request.method
 
     return user_input
 
@@ -583,6 +540,18 @@ def stored_xss(request):
     return HttpResponse(html)
 
 
+def trust_boundary_violation(request):
+    user_input = request.GET.get("user_input")
+    setdefault = request.GET.get("setdefault") == "True"
+
+    if setdefault:
+        request.session.setdefault("whatever", user_input)
+    else:
+        request.session["whatever"] = user_input
+
+    return HttpResponse("<p>Trust boundary violation</p>")
+
+
 def get_apptest_urls():
     # New url/views should be added to this list
     url_mappings = [
@@ -598,8 +567,6 @@ def get_apptest_urls():
         ("cookie-source", cookie_source),
         ("header-source", header_source),
         ("header-key-source", header_key_source),
-        ("untrusted-yaml", untrusted_yaml),
-        ("untrusted-pickle", untrusted_pickle),
         ("xss", xss),
         ("xss-jinja", xss_jinja),
         ("xss-mako", xss_mako),
@@ -611,10 +578,11 @@ def get_apptest_urls():
         ("ssrf-dynamic", ssrf_dynamic),
         ("unvalidated-redirect", unvalidated_redirect),
         ("two-vulns", two_vulns),
-        ("untrusted-exec", untrusted_exec),
         ("untrusted-execfile", untrusted_execfile),
         ("dynamic-sources", dynamic_sources),
         ("stored-xss", stored_xss),
+        ("xpath-injection", xpath_injection),
+        ("trust-boundary-violation", trust_boundary_violation),
     ]
 
     return [create_url_definition(name, view) for name, view in url_mappings]
