@@ -5,7 +5,8 @@ from collections import OrderedDict
 import inspect
 import sys
 
-from contrast.extern.six import iteritems
+from contrast.utils.decorators import fail_safely
+from contrast.extern.six import iteritems, PY2
 
 from contrast.agent.policy import patch_manager
 from contrast.utils.ignored_modules import (
@@ -182,9 +183,15 @@ def is_patchable(obj):
     return inspect.isroutine(obj) and not is_unpatchable_builtin_method
 
 
+@fail_safely("Unable to repatch single module", log_level="exception")
 def repatch_module(module):
     """Repatch a single module. See docstring for repatch_imported_modules"""
-    for attr_name, attr in vars(module).items():
+
+    # dict.items() returns a copy in Python 2. Didn't want to make another copy so doing list(...)
+    # in a separate PY3 block. In Python 3 dict.items() returns a dict_view not a copy.
+    module_attrs = vars(module).items() if PY2 else list(vars(module).items())
+
+    for attr_name, attr in module_attrs:
         try:
             if not is_patchable(attr):
                 continue
@@ -204,6 +211,7 @@ def repatch_module(module):
         patch_manager.patch(module, attr_name)
 
 
+@fail_safely("Unable to patch previously imported modules", log_level="exception")
 def repatch_imported_modules():
     """
     Applies patches to modules that were already imported prior to agent startup
